import { OutboxMessage } from '../common/message';
import { ConcurrencyController } from './concurrency-controller';
export type MultiConcurrencyType = 'mutex' | 'full-concurrency' | 'discriminating-mutex';
/**
 * Use different mutex controllers depending on the desired concurrency level
 * for different messages. If a discriminating mutex should be used, the
 * discriminator function must be supplied as well.
 * @param getConcurrencyType Implements the logic which concurrency controller should be used e.g. based on the aggregate and message type
 * @param discriminator The discriminator to find or create a mutex for when using the discriminating mutex.
 * @returns The controller to acquire and release the mutex for a specific discriminator
 */
export declare const createMultiConcurrencyController: (getConcurrencyType: (message: OutboxMessage) => MultiConcurrencyType, discriminator?: ((message: OutboxMessage) => string) | undefined) => ConcurrencyController;
//# sourceMappingURL=create-multi-concurrency-controller.d.ts.map