import { ClientBase } from 'pg';
import { OutboxMessage } from '../common/message';
import { OutboxConfig } from './outbox-listener';
/**
 * Pre-configure the specific kind of outbox message to generate and receive a
 * function that can be called to actually store the specific outbox message.
 * @param aggregateType The aggregate root type that was responsible to create this message.
 * @param messageType The type of message that happened on the aggregate type.
 * @param config The configuration object that defines the outbox table schema.
 * @returns The function to store the outbox message data to the database.
 */
export declare const initializeOutboxMessageStorage: (aggregateType: string, messageType: string, { settings: { dbSchema, dbTable } }: Pick<OutboxConfig, 'settings'>) => (aggregateId: string, payload: unknown, dbClient: ClientBase, metadata?: Record<string, unknown>) => Promise<OutboxMessage>;
/**
 * Create a general outbox message storage with only the DB settings to generate
 * and receive a function that can be called to actually store the specific
 * outbox message while supplying also the aggregate type and message type.
 * @param config The configuration object that defines the outbox table schema.
 * @returns The function to store the outbox message data to the database.
 */
export declare const initializeGeneralOutboxMessageStorage: ({ settings: { dbSchema, dbTable }, }: Pick<OutboxConfig, 'settings'>) => (aggregateId: string, aggregateType: string, messageType: string, payload: unknown, dbClient: ClientBase, metadata?: Record<string, unknown>) => Promise<OutboxMessage>;
//# sourceMappingURL=outbox-message-storage.d.ts.map