"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultListenerRestartTimeStrategy = void 0;
/**
 * The default listener restart time strategy checks if the error message is a
 * PostgreSQL error telling that the replication slot is in use. If this is the
 * case it will wait for the configured `restartDelaySlotInUse` (default: 10sec)
 * and otherwise for the configured `restartDelay` (default: 250ms).
 */
const defaultListenerRestartTimeStrategy = ({ settings: { restartDelay, restartDelaySlotInUse }, }) => {
    return (error) => {
        const err = error;
        if ((err === null || err === void 0 ? void 0 : err.code) === '55006' && (err === null || err === void 0 ? void 0 : err.routine) === 'ReplicationSlotAcquire') {
            return restartDelaySlotInUse !== null && restartDelaySlotInUse !== void 0 ? restartDelaySlotInUse : 10000;
        }
        else {
            return restartDelay !== null && restartDelay !== void 0 ? restartDelay : 250;
        }
    };
};
exports.defaultListenerRestartTimeStrategy = defaultListenerRestartTimeStrategy;
//# sourceMappingURL=listener-restart-time-strategy.js.map