import { ClientBase } from 'pg';
import { TransactionalLogger } from '../common/logger';
import { InboxMessage } from '../common/message';
import { InboxConfig } from '../inbox/inbox-listener';
/**
 * Create a client instance from the pool. This can be helpful if some message
 * handlers have to use different PostgreSQL roles or if you need to set some
 * PostgreSQL configuration values for the client connection.
 */
export interface MessageProcessingClientStrategy {
    /**
     * Decide based on the message which database client should be used to process
     * the message handler and the update to the message in the inbox table.
     * @param message The inbox message
     * @returns The PostgreSQL client to use to process the message
     */
    getClient: (message: InboxMessage) => Promise<ClientBase>;
    shutdown: () => Promise<void>;
}
/**
 * The default message processing uses a single pool based on the configured
 * `pgConfig` settings.
 */
export declare const defaultMessageProcessingClientStrategy: (config: InboxConfig, logger: TransactionalLogger) => MessageProcessingClientStrategy;
//# sourceMappingURL=message-processing-client-strategy.d.ts.map