"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultMessageProcessingClientStrategy = void 0;
const pg_1 = require("pg");
/**
 * The default message processing uses a single pool based on the configured
 * `pgConfig` settings.
 */
const defaultMessageProcessingClientStrategy = (config, logger) => {
    const pool = new pg_1.Pool(config.pgConfig);
    pool.on('error', (err) => {
        logger.error(err, 'PostgreSQL pool error');
    });
    return {
        getClient: (_message) => __awaiter(void 0, void 0, void 0, function* () { return yield pool.connect(); }),
        shutdown: () => __awaiter(void 0, void 0, void 0, function* () {
            pool.removeAllListeners();
            try {
                yield pool.end();
            }
            catch (e) {
                logger.error(e, 'Message processing pool shutdown error');
            }
        }),
    };
};
exports.defaultMessageProcessingClientStrategy = defaultMessageProcessingClientStrategy;
//# sourceMappingURL=message-processing-client-strategy.js.map